bo4e.schemata package
=====================

Submodules
----------

bo4e.schemata.caseconverterschema module
----------------------------------------

.. automodule:: bo4e.schemata.caseconverterschema
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bo4e.schemata
   :members:
   :undoc-members:
   :show-inheritance:
